# -*- coding: utf-8 -*-
#
#    Copyright 2019 Fabien Bourgeois <fabien@yaltik.com>
#    Copyright 2019 Youssef El Ouahby <youssef@yaltik.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

""" GOLEM Members Analysis Pivot Adaption """

from odoo import models, fields, api


class GolemMemberAnalysisPivot(models.TransientModel):
    """ GOLEM Members Analysis Pivot Adaption """
    _inherit = 'golem.member.analysis'
    _description = 'GOLEM Members Analysis Adaption'


    family_quotient_slice_id = fields.Many2one(
        'golem.payment.rule.familyquotient.slice', index=True, ondelete='cascade',
        store=True, compute='_compute_family_quotient_slice_id'
    )

    @api.depends('family_quotient')
    def _compute_family_quotient_slice_id(self):
        """ Computes family quotient slice """
        for rec in self:
            if rec.family_quotient:
                fq_int = int(rec.family_quotient)
                domain = [('family_quotient_from', '<=', fq_int),
                          ('family_quotient_to', '>=', fq_int)]
                rule_slice_id = self.env['golem.payment.rule.familyquotient.slice'].search(
                    domain, limit=1
                )
                if rule_slice_id:
                    rec.family_quotient_slice_id = rule_slice_id
